@@ -6,7 +6,7 @@
 
 #include "calculator.h"
 
-#include <QDebug>
+#include "kalzium_debug.h"
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QIcon>
@@ -22,7 +22,7 @@
 calculator::calculator(QWidget *parent) : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Chemical Calculator"));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Help|QDialogButtonBox::Close);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Help|QDialogButtonBox::Close, this);
     QWidget *mainWidget = new QWidget(this);
     QVBoxLayout *mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
@@ -91,7 +91,7 @@ void calculator::slotItemSelection(QTreeWidgetItem *item)
     }
 
     //DEBUG
-    qDebug() << "Item clicked: " << item->text(0);
+    qCDebug(KALZIUM_LOG) << "Item clicked: " << item->text(0);
 
     QString s = item->text(0);
 
