@@ -31,18 +31,18 @@ IsotopeScene::~IsotopeScene()
 
 void IsotopeScene::updateContextHelp(IsotopeItem * item)
 {
-    emit itemSelected(item);
+    Q_EMIT itemSelected(item);
 }
 
 void IsotopeScene::drawIsotopes()
 {
-    QList<Element*> elist = KalziumDataObject::instance()->ElementList;
+    const QList<Element*> elist = KalziumDataObject::instance()->ElementList;
     int mode = 0;
 
     foreach (Element *e, elist) {
         int elementNumber = e->dataAsVariant(ChemicalDataObject::atomicNumber).toInt();
 
-        QList<Isotope*> ilist = KalziumDataObject::instance()->isotopes(elementNumber);
+        const QList<Isotope*> ilist = KalziumDataObject::instance()->isotopes(elementNumber);
         foreach (Isotope *i, ilist) {
             int x = elementNumber * m_itemSize;
             int y = (300 - i->nucleons()) * m_itemSize;
