@@ -5,7 +5,7 @@
 
 #include "spectrumviewimpl.h"
 
-#include <QDebug>
+#include "kalzium_debug.h"
 #include <QTableWidget>
 #include <QTreeWidget>
 
@@ -85,7 +85,7 @@ void SpectrumViewImpl::updatePeakInformation(Spectrum::peak *peak)
 {
     double peakWavelength = peak->wavelengthToUnit(Prefs::spectrumWavelengthUnit());
 
-    QList<QTreeWidgetItem *> foundItems = peakListTable->findItems(QString::number(peakWavelength),
+    const QList<QTreeWidgetItem *> foundItems = peakListTable->findItems(QString::number(peakWavelength),
                                           Qt::MatchExactly);
 
     if (foundItems.isEmpty()) {
@@ -93,7 +93,7 @@ void SpectrumViewImpl::updatePeakInformation(Spectrum::peak *peak)
     }
 
     foreach (QTreeWidgetItem * item, peakListTable->selectedItems())
-    item->setSelected(false);
+        item->setSelected(false);
 
     foundItems.first()->setSelected(true);
     peakListTable->scrollToItem(foundItems.first());
@@ -103,9 +103,9 @@ void SpectrumViewImpl::setUnit()
 {
     Prefs::setSpectrumWavelengthUnit(m_lengthUnit->getCurrentUnitId());
     Prefs::self()->save();
-    qDebug() << "Unit changed: " << m_lengthUnit->getCurrentUnitId();
+    qCDebug(KALZIUM_LOG) << "Unit changed: " << m_lengthUnit->getCurrentUnitId();
 
-    emit settingsChanged();
+    Q_EMIT settingsChanged();
     fillPeakList();
 }
 
